subroutine read_cod
!! Subroutine, which reads the flags from the file basins.cod
!! Copyright (C) 2004  Thorsten Pohlert
!!
!! This program is free software; you can redistribute it and/or modify
!! it under the terms of the GNU General Public License as published by
!! the Free Software Foundation; either version 2 of the License, or
!! (at your option) any later version.
!!
!! You should have received a copy of the GNU General Public License
!! along with this program; if not, write to the Free Software
!! Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
!!
!! VARIABLES
!! ---------
!! aa             LOGICAL                Test, whether file exists
!! 
!! nbyr           INTEGER                Number of years simulated  (NOT USED YET)
!! iyr                                   Beginning year of simulation (NOT USED YET)
!! idaf                                  Beginning julian day of simulation (NOT USED YET)
!! idal                                  Ending julian day of simulation (NOT USED YET)
!! i                                     Counter
!! ipd                                   Print code (month, day, year)
!! nyskip                                Number of years to skip output printing/summarization (NOT USED YET)
!!
!! INTRINSICS
!! ----------
!! COUNT
!!
!! TP:
!! The variables, which aren ot used yet, might be used to allocate the arrays
!! in a later version.

use globals
implicit none

logical:: aa
integer:: nbyr, iyr, idaf, idal, i, ipd, nyskip

! See, whether file exists
inquire(file='basins.cod',exist=aa)
  if (aa == .false.) then
     write(*,*) 'ERROR: basins.cod does not exist!'
     write(*,*) 'Check, if you are in the correct directory!'
     write(*,*)
     write(*,*) 'READOUT exits without success!' 
     stop
  end if

open(20,file='basins.cod',status='old')
!Skip the first line, read simulation period
read(20,*)
read(20,*) nbyr
read(20,*) iyr
read(20,*) idaf
read(20,*) idal
read(20,*) ipd
read(20,*) nyskip
! Annual printout frequency?
if (ipd == 2) then
  write(*,*) 'ERROR: You choose annual printout frequency!'
  write(*,*) 'READOUT will not work with this option.'
  write(*,*)
  write(*,*) 'READOUT exits without success!' 
  stop
end if  

do i = 8, 28
  read(20,*)
end do

!Read the printout flags
read(20,*) (rchfla(i),i = 1, 20)
read(20,*)
read(20,*) (bsbfla(i),i = 1, 20)
read(20,*)
read(20,*) (sbsfla(i),i = 1, 20)
close(20)

! Get the flags
nr1 = count(mask=(rchfla > 0))
nr2 = count(mask=(bsbfla > 0))
nr3 = count(mask=(sbsfla > 0))

if (nr1 == 0) then
   flag1 = 0
end if
if (nr2 == 0) then
   flag2 = 0
end if
if (nr3 == 0) then
   flag3 = 0
end if

end subroutine
