subroutine readout_bsb
!! Subroutine, which extracts data from basins.bsb file
!! Copyright (C) 2004  Thorsten Pohlert
!!
!! This program is free software; you can redistribute it and/or modify
!! it under the terms of the GNU General Public License as published by
!! the Free Software Foundation; either version 2 of the License, or
!! (at your option) any later version.
!!
!! You should have received a copy of the GNU General Public License
!! along with this program; if not, write to the Free Software
!! Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
!!
!! VARIABLES
!! ---------
!! aa             LOGICAL                Test, whether file exists
!!
!! i, j, k        INTEGER                Counters
!! rch                                   Reach / Subbasin
!! mon                                   Daily / monthly index
!! eof                                   End-of-file variable
!! choice                                The selected reach /subbasin
!! yesno                                 YES = 1, NO = 2
!! mxrch                                 Maximum number of reaches / subbasins
!! 
!! maxval         INTEGER,PARAMETER      Maximum Nr. of variables in file to be extracted
!!
!! sum            REAL                   Counter of lines in file
!! size                                  Array size
!!
!! head           CHARACTER(:)           Array containing the names of the variables in
!!                                       the file header
!!
!! yy             REAL(:)                'Moving-window' to read in the selected variable
!!
!! INTRINSICS
!! ---------
!! INT, REAL, MAX


use globals
implicit none
logical:: aa
integer:: i, j, k, rch, mon
integer:: eof, choice, yesno, mxrch

real:: sum, size

integer,parameter:: maxval = 15
real,dimension(maxval):: yy
character(len=10),dimension(maxval):: head

! See, whether file exists
inquire(file='basins.bsb',exist=aa)
  if (aa == .false.) then
     write(*,*) 'ERROR: basins.bsb does not exist!'
     write(*,*) 'Check, if you are in the correct directory!'
     write(*,*)
     write(*,*) 'Exit program READOUT!' 
     stop
  end if

! Open file
open(10,file='basins.bsb',status='old')

! Dialog:
write(*,*)
write(*,1000) 'READOUT BASINS.BSB: Subbasin Output File'
write(*,*)
write(*,1000) 'Please enter the number of the subbasin you want to extract!'
write(*,*)
read(*,1001) choice

! Some more questions
do !Inner loop
  do !Outer loop
    write(*,*)
    write(*,1000) 'Please select the variable:'
    write(*,*)

!! Print the variables to the screen and read users selection
    if (flag2 == 0) then
      do i = 1, 5
         j = i + 5
         k = i + 10
        write(*,3000) bsbvar(i), i, bsbvar(j), j, bsbvar(k), k
      end do
    else
      do i = 1, nr2
      write(*,1000) '!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'
      write(*,1000) 'CAUTION: You have customized your basins.cod!'
      write(*,1000) 'Check careful, whether READOUT returns you'
      write(*,1000) 'the correct variable!'
      write (*,*)
        write(*, 5000) bsbvar(bsbfla(i)), i
5000    format(a, 1X, i2)
      end do
    end if 
    read(*,1001) value

! Test the selection
      if(value < 1 .or. value > maxval) then
        write(*,*)
        write(*,1003) 'ERROR: you choose', value, ', which does not exist!'
        write(*,1000) 'Please repeat or QUIT READOUT with CRT-C!'
        write(*,*)
        cycle
      else
        exit
      end if
  end do
  
! Read input-file and skip the first 8 rows
  do i = 1, 8
    read(10,*)
  end do
! Read Header of columns (line 9)
  read(10,1005) (head(i), i = 1, maxval)

  write(*,*)
  write(*,1004) 'You selected ', head(value)
  write(*,1000) 'Is this correct?'
  write(*,*)
  write(*,1000) 'Yes                      1'
  write(*,1000) 'No                       2'
  read(*,1001) yesno
    if (yesno .ne. 1) then
      write(*,*)
      write(*,1000) 'Please change your selection!'
      rewind(10) !Go to first row of file
      cycle
    else
      exit ! Leave infinite loop
    end if
end do

! Get the Nr of rows and array size
i = 0
sum = 0.0
eof = 0
do while (eof == 0)
  read(10,1006,iostat=eof) mxrch
    sum = sum + 1.0
    mxrch = max(mxrch, i)
end do

!Check wether selected reach existst!
if (choice > mxrch) then
   write(*,*)
   write(*,1000) 'ERROR: Your selected reach does not exist!'
   write(*,1003) 'There are', mxrch, ' subbasins in your project!'
   write(*,*)
   write(*,1000) 'Please run READOUT again!'
   write(*,1000) 'READOUT exits without success!'
   stop
end if

! Adjust sum and allocate arrays!
 sum = sum - 1.0
 size = 1.0 + sum / real(mxrch)
 asize = int(size)
 allocate (xx(asize), amon(asize))

! Now rewind and read in the data
write(*,1000) 'Reading data from basins.bsb ...'
rewind(10) ! Go back to first row in file
do i = 1, 9 
  read(10,*)
end do
  j = 0
  eof = 0
    do while (eof == 0)
      read(10,1008,iostat=eof) rch, mon, (yy(k), k = 1, maxval)
        if (eof < 0) then
          exit
        end if
        if (rch == choice .and. mon <= 366) then
          j = j + 1
          xx(j) = yy(value)
          amon(j) = mon
        end if
    end do

!Give actual information about records
rec = j

!Close the file
close(10)

! Write output results!
call write_bsb (head)

1000 format(a)
1001 format(i3)
1003 format(a, 1X, i3, a)
1004 format(a,a)
1005 format(35X, 15a10)
1006 format(6X, i4)
1008 format(6X, i4, 10X, i4, 10X, 15f10.3)
3000 format(a, 1X, i2, 4X, a, 1X, i2, 4X, a, 1X, i2) 
end subroutine
